--
-- Mod: FS19_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersTreeLogPrices by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.0.1.0
-- Version 1.0.1.1 - no change
-- Version 1.0.1.2 - no change
-- Version 1.0.1.3 - no change
-- Version 1.0.1.4 - no change
-- Version 1.0.1.5 - no change
-- Version 1.0.1.6 - no change
-- Version 1.0.1.7 - no change
-- Version 1.0.1.8 - no change
-- Version 1.0.1.9 - no change
-- Version 1.0.2.0 - no change
-- Version 1.0.2.1 - no change
-- Version 1.0.2.2 - no change
-- Version 1.0.2.3 - no change
-- Version 1.0.3.0 - no change

--[[

This script adjusts the sell price of different types of tree logs. The input parameters
are defined below.

The user should adjust the prices of milled lumber to local pricing levels.

Searching the internet will give different types of price information:

	Stumpage:

		The price you get for a standing tree. The buyer does the felling and hauling. This is
		not the way it can be done in Farming Simulator.

	Roadside sawlogs:

		The price you get for roundwood logs picked up at the roadside. You do the felling, the buyer
		picks up the logs from roadside stacks.

	Sawlogs:

		Roundwood logs cut to uniform length. Has bark.

	Lumber:

		Processed logs, cut into boards.

Board foot:

	The unit of volume of wood in the wood trading business.
	1 BFT = 1 square foot x 1 inch = 2.35973722 liters.
	1 MBFT = 1000 BFT = 2.35973722 cubic meters.

	1 MBFT = 5 - 7 Tonnes soft wood (pine, spruce, poplar)
	1 MBFT = 7 - 9 Tonnes hard wood (ash, beech, birch, larch, locust, mahogany, maple, oak)

Unit conversion

	Logging companies and sawmills often gives prices per MBFT.
	Goverments often give prices per Tonnes or per cubic meter (m3).

	In this mod, input price level for milled lumber is given per MBFT, as this is the most readily available
	information on the internet.

	MBFT is a volume unit. It is a measure of how much cut board volume you get out of a given
	mass of wood. This varies between hard wood and soft wood trees.

	It takes 5 - 7 Tonnes of soft wood tree to produce 1 MBFT cut boards.
	It takes 7 - 9 Tonnes of hard wood tree to produce 1 MBFT cut boards.

	Hence we can convert from currency/MBFT to currency/Tonnes as follows:

	Price/Tonnes = (Price/MBFT)  / (Tonnes/MBFT)

	Price/1000 L = (Price/Tonnes) * (kg/Liter)

	A random price variation is implemented.

Lumber yard log price

	The price for unmilled logs cut and delivered to the lumber yard is obtained
	by deducting the lumber yard costs and profit (50 % of fixed and variable costs)
	from the price of milled wood.

--]]

RealNumbersTreeLogPrices = {};

function myPrint(text, number, textWidth, unit)
	print(string.format("%s =  %8.0f %s", text..string.rep(" ",textWidth-string.len(text)),number,"    "..unit));
end;
function myPrintFloat(text, number, textWidth, unit)
	print(string.format("%s =  %12.4f %s", text..string.rep(" ",textWidth-string.len(text)),number, unit));
end;

function RealNumbersTreeLogPrices:loadMap()

	local textWidth = 60;
	local textWidth2 = 15;
	local currency ="€";
	local randomness = 1; 			--1: on, 0: off

	RN.notRunYetRealNumbersTreeLogPrices = true;
	RN.upStartRealNumbersTreeLogPrices = true;

	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

	print("\n --- RealNumbersTreeLogPrices active --- \n")

	print("MBFT : 1000 board feet = 1000 square feet x 1 inch thick = 2.35973722 cubic meters");
	print("Tonnes per MBFT is how many tonnes of barked tree logs is needed to produce 2.36 cubic meters of cut boards");
	print("Price per milled MBFT is the input price. Adjust this in RealNumbersTreeLogPrices");
	print("Random price variation is used to simulate variation in log quality");
	print("Random price variation can be adjusted in RealNumbersTreeLogPrices.lua");
	print("Random price variation can be turned off in RealNumbersTreeLogPrices.lua");
	print("Fixed and variable lumber yard costs are deducted from milled wood prices");
	print("to obtain price per MBFT for harvested and delivered logs.");
	print("Log prices are converted to tonnes and 1000 L");
	print(" ");


-- Tree data

	-- 1 MBFT = 2359.74 L = 2.36 m3 of board wood
	-- 1 MBFT = 7 Tonnes for soft wood ~ 4 - 6 m3 roundwood (timber logs)
	-- Expenses (typical values)
	-- Logging	: 100 USD/MBFT =  89.0 EU/MBFT  =  75.0 £/MBFT
	-- Trucking	: 100 USD/MBFT =  89.0 EU/MBFT 	=  75.0 £/MBFT
	-- Milling	: 250 USD/MBFT = 222.5 EU/MBFT 	= 187.5 £/MBFT



	RN.milledWoodPricePerMBFT 				= {};
	RN.logsPricePerMBFT 					= {};
	RN.logsPricePerTonnes 					= {};
	RN.logsPricePerLiter 					= {};
	RN.logDeliveredPricePerLiter			= {};
	RN.lumberPriceVariation					= {};
	RN.treeRandomPriceFactor				= {};
	RN.woodChipsPerLiter					= {};
	RN.woodDensity							= {};
	RN.tonnesWoodPerMBFT					= {};  	-- Tonnes of wood per MBFT
	RN.woodDeliveryPerMBFT					= {};	-- Delivery fee to sawmill, price per 1000 L
	RN.woodDeliveryPerTonnes				= {};
	RN.woodDeliveryPerLiter					= {};
	RN.loggingTrees							= {};

-- common expenses

	RN.variableLumberYardCost				= 100; 	-- eu/£/$ per MBFT
	RN.fixedLumberYardCost					=  35; 	-- eu/£/$ per MBFT
	RN.lumberYardProfit						=  50;  -- Percentage of variable and fixed cost
	RN.totalLumberYardCost					= (RN.variableLumberYardCost+RN.fixedLumberYardCost)*(1 + RN.lumberYardProfit/100);

	RN.loggingTrees.names 					= "AMERICANELM ASH ASPEN BEECH BETULAERMANII BIRCH BOXELDER CHERRY CHINESEELM CYPRESS "..
	                                          "DOWNYSERVICEBERRY GIANTSEQUOIA GOLDENRAIN JAPANESEZELKOVA LARCH LOCUST LODGEPOLEPINE MAHOGANY MAPLE OAK "..
	                                          "NORTHERNCATALPA OLIVETREE PAGODADOGWOOD PINE PINUSSYLVESTRIS PINUSTABULIFORMIS PONDEROSAPINE POPLAR "..
											  "RAVAGED SHAGBARKHICKORY SPRUCE STONEPINE TILIAAMURENSIS TRANSPORT WILLOW DEADWOOD APPLE";

	RN.woodDensity.AMERICANELM 				= 0.56; -- kg/L
	RN.tonnesWoodPerMBFT.AMERICANELM 		= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.AMERICANELM 	= 1500;	-- Price per MBFT
	RN.logsPricePerLiter.AMERICANELM		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.AMERICANELM 		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.AMERICANELM 		= 3.4;
	RN.lumberPriceVariation.AMERICANELM 	= 30;	-- Percent price variation on tree logs

	RN.woodDensity.ASPEN					= 0.83; -- kg/L
	RN.tonnesWoodPerMBFT.ASPEN				= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.ASPEN			= 800;	-- Price per MBFT
	RN.logsPricePerLiter.ASPEN				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.ASPEN			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.ASPEN				= 3.4;
	RN.lumberPriceVariation.ASPEN			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.ASH						= 0.83; -- kg/L
	RN.tonnesWoodPerMBFT.ASH				= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.ASH			= 800;	-- Price per MBFT
	RN.logsPricePerLiter.ASH				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.ASH				= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.ASH				= 3.4;
	RN.lumberPriceVariation.ASH				= 30;	-- Percent price variation on tree logs

	RN.woodDensity.BEECH					= 0.86; -- kg/L
	RN.tonnesWoodPerMBFT.BEECH				= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.BEECH			= 420;	-- Price per MBFT
	RN.logsPricePerLiter.BEECH				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.BEECH			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.BEECH				= 3.4;
	RN.lumberPriceVariation.BEECH			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.BIRCH					= 0.86; -- kg/L
	RN.tonnesWoodPerMBFT.BIRCH				= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.BIRCH			= 420;	-- Price per MBFT
	RN.logsPricePerLiter.BIRCH				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.BIRCH			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.BIRCH				= 3.2;
	RN.lumberPriceVariation.BIRCH			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.BETULAERMANII			= 0.86; -- kg/L
	RN.tonnesWoodPerMBFT.BETULAERMANII		= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.BETULAERMANII	= 420;	-- Price per MBFT
	RN.logsPricePerLiter.BETULAERMANII		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.BETULAERMANII	= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.BETULAERMANII		= 3.2;
	RN.lumberPriceVariation.BETULAERMANII	= 30;	-- Percent price variation on tree logs

	RN.woodDensity.BOXELDER 				= 0.65; -- kg/L
	RN.tonnesWoodPerMBFT.BOXELDER 			= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.BOXELDER 		= 1400;	-- Price per MBFT
	RN.logsPricePerLiter.BOXELDER			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.BOXELDER 		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.BOXELDER 			= 3.2;
	RN.lumberPriceVariation.BOXELDER 		= 30;	-- Percent price variation on tree logs

	RN.woodDensity.CHERRY 					= 0.86; -- kg/L
	RN.tonnesWoodPerMBFT.CHERRY 			= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.CHERRY 		= 950;	-- Price per MBFT
	RN.logsPricePerLiter.CHERRY				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.CHERRY 			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.CHERRY 			= 3.2;
	RN.lumberPriceVariation.CHERRY 			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.CHINESEELM				= 0.80; -- kg/L
	RN.tonnesWoodPerMBFT.CHINESEELM			= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.CHINESEELM	= 500;	-- Price per MBFT
	RN.logsPricePerLiter.CHINESEELM			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.CHINESEELM		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.CHINESEELM			= 3.0;
	RN.lumberPriceVariation.CHINESEELM		= 50;	-- Percent price variation on tree logs

	RN.woodDensity.CYPRESS 					= 0.65; -- kg/L
	RN.tonnesWoodPerMBFT.CYPRESS 			= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.CYPRESS 		= 1400;	-- Price per MBFT
	RN.logsPricePerLiter.CYPRESS			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.CYPRESS 			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.CYPRESS 			= 3.2;
	RN.lumberPriceVariation.CYPRESS 		= 30;	-- Percent price variation on tree logs

	RN.woodDensity.DOWNYSERVICEBERRY				= 0.86; -- kg/L
	RN.tonnesWoodPerMBFT.DOWNYSERVICEBERRY			= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.DOWNYSERVICEBERRY		= 420;	-- Price per MBFT
	RN.logsPricePerLiter.DOWNYSERVICEBERRY			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.DOWNYSERVICEBERRY		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.DOWNYSERVICEBERRY			= 3.8;
	RN.lumberPriceVariation.DOWNYSERVICEBERRY		= 50;	-- Percent price variation on tree logs

	RN.woodDensity.GIANTSEQUOIA				= 1.00; -- kg/L
	RN.tonnesWoodPerMBFT.GIANTSEQUOIA		= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.GIANTSEQUOIA	= 1015;	-- Price per MBFT
	RN.logsPricePerLiter.GIANTSEQUOIA		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.GIANTSEQUOIA		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.GIANTSEQUOIA		= 3.0;
	RN.lumberPriceVariation.GIANTSEQUOIA	= 50;	-- Percent price variation on tree logs

	RN.woodDensity.GOLDENRAIN				= 1.00; -- kg/L
	RN.tonnesWoodPerMBFT.GOLDENRAIN			= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.GOLDENRAIN	= 1015;	-- Price per MBFT
	RN.logsPricePerLiter.GOLDENRAIN			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.GOLDENRAIN		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.GOLDENRAIN			= 3.0;
	RN.lumberPriceVariation.GOLDENRAIN		= 50;	-- Percent price variation on tree logs

	RN.woodDensity.JAPANESEZELKOVA					= 0.85; -- kg/L
	RN.tonnesWoodPerMBFT.JAPANESEZELKOVA			= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.JAPANESEZELKOVA		= 700;	-- Price per MBFT
	RN.logsPricePerLiter.JAPANESEZELKOVA			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.JAPANESEZELKOVA			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.JAPANESEZELKOVA			= 3.4;
	RN.lumberPriceVariation.JAPANESEZELKOVA			= 40;	-- Percent price variation on tree logs

	RN.woodDensity.LARCH					= 0.80; -- kg/L
	RN.tonnesWoodPerMBFT.LARCH				= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.LARCH			= 500;	-- Price per MBFT
	RN.logsPricePerLiter.LARCH				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.LARCH			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.LARCH				= 3.0;
	RN.lumberPriceVariation.LARCH			= 50;	-- Percent price variation on tree logs

	RN.woodDensity.LOCUST					= 0.86; -- kg/L
	RN.tonnesWoodPerMBFT.LOCUST				= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.LOCUST		= 420;	-- Price per MBFT
	RN.logsPricePerLiter.LOCUST				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.LOCUST			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.LOCUST				= 3.8;
	RN.lumberPriceVariation.LOCUST			= 50;	-- Percent price variation on tree logs

	RN.woodDensity.LODGEPOLEPINE			= 1.00; -- kg/L
	RN.tonnesWoodPerMBFT.LODGEPOLEPINE		= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.LODGEPOLEPINE	= 900;	-- Price per MBFT 81 USD/m3
	RN.logsPricePerLiter.LODGEPOLEPINE		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.LODGEPOLEPINE	= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.LODGEPOLEPINE		= 3.4;
	RN.lumberPriceVariation.LODGEPOLEPINE	= 40;	-- Percent price variation on tree logs

	RN.woodDensity.MAHOGANY					= 1.00; -- kg/L
	RN.tonnesWoodPerMBFT.MAHOGANY			= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.MAHOGANY		= 1015;	-- Price per MBFT
	RN.logsPricePerLiter.MAHOGANY			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.MAHOGANY			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.MAHOGANY			= 3.0;
	RN.lumberPriceVariation.MAHOGANY		= 50;	-- Percent price variation on tree logs

	RN.woodDensity.MAPLE					= 0.85; -- kg/L
	RN.tonnesWoodPerMBFT.MAPLE				= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.MAPLE			= 700;	-- Price per MBFT
	RN.logsPricePerLiter.MAPLE				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.MAPLE			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.MAPLE				= 3.4;
	RN.lumberPriceVariation.MAPLE			= 40;	-- Percent price variation on tree logs

	RN.woodDensity.NORTHERNCATALPA 				= 0.99; -- kg/L
	RN.tonnesWoodPerMBFT.NORTHERNCATALPA 		= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.NORTHERNCATALPA 	= 3500;	-- Price per MBFT
	RN.logsPricePerLiter.NORTHERNCATALPA		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.NORTHERNCATALPA 		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.NORTHERNCATALPA 		= 3.4;
	RN.lumberPriceVariation.NORTHERNCATALPA 	= 40;	-- Percent price variation on tree logs

	RN.woodDensity.OAK						= 0.74; -- kg/L
	RN.tonnesWoodPerMBFT.OAK				= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.OAK			= 700;	-- Price per MBFT 375; 21 USD/m3
	RN.logsPricePerLiter.OAK				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.OAK				= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.OAK				= 7.5;
	RN.lumberPriceVariation.OAK				= 30;	-- Percent price variation on tree logs

	RN.woodDensity.OLIVETREE 				= 0.99; -- kg/L
	RN.tonnesWoodPerMBFT.OLIVETREE 			= 9.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.OLIVETREE 	= 3500;	-- Price per MBFT
	RN.logsPricePerLiter.OLIVETREE			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.OLIVETREE 		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.OLIVETREE 			= 3.4;
	RN.lumberPriceVariation.OLIVETREE 		= 40;	-- Percent price variation on tree logs

	RN.woodDensity.PAGODADOGWOOD 			= 0.60; -- kg/L
	RN.tonnesWoodPerMBFT.PAGODADOGWOOD 		= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.PAGODADOGWOOD = 650;	-- Price per MBFT 250
	RN.logsPricePerLiter.PAGODADOGWOOD		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.PAGODADOGWOOD 	= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.PAGODADOGWOOD 		= 3.0;
	RN.lumberPriceVariation.PAGODADOGWOOD 	= 30;	-- Percent price variation on tree logs

	RN.woodDensity.PINE						= 0.60; -- kg/L
	RN.tonnesWoodPerMBFT.PINE				= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.PINE			= 450;	-- Price per MBFT 250
	RN.logsPricePerLiter.PINE				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.PINE				= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.PINE				= 3.0;
	RN.lumberPriceVariation.PINE			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.PINUSSYLVESTRIS 				= 0.60; -- kg/L
	RN.tonnesWoodPerMBFT.PINUSSYLVESTRIS 		= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.PINUSSYLVESTRIS 	= 650;	-- Price per MBFT 250
	RN.logsPricePerLiter.PINUSSYLVESTRIS		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.PINUSSYLVESTRIS 		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.PINUSSYLVESTRIS 		= 3.0;
	RN.lumberPriceVariation.PINUSSYLVESTRIS 	= 30;	-- Percent price variation on tree logs

	RN.woodDensity.PINUSTABULIFORMIS			= 0.60; -- kg/L
	RN.tonnesWoodPerMBFT.PINUSTABULIFORMIS		= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.PINUSTABULIFORMIS	= 450;	-- Price per MBFT 250
	RN.logsPricePerLiter.PINUSTABULIFORMIS		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.PINUSTABULIFORMIS	= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.PINUSTABULIFORMIS		= 3.0;
	RN.lumberPriceVariation.PINUSTABULIFORMIS	= 30;	-- Percent price variation on tree logs

	RN.woodDensity.PONDEROSAPINE			= 0.74; -- kg/L
	RN.tonnesWoodPerMBFT.PONDEROSAPINE		= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.PONDEROSAPINE	= 700;	-- Price per MBFT 375; 21 USD/m3
	RN.logsPricePerLiter.PONDEROSAPINE		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.PONDEROSAPINE	= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.PONDEROSAPINE		= 7.5;
	RN.lumberPriceVariation.PONDEROSAPINE	= 30;	-- Percent price variation on tree logs

	RN.woodDensity.POPLAR					= 0.74; -- kg/L
	RN.tonnesWoodPerMBFT.POPLAR				= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.POPLAR		= 700;	-- Price per MBFT 375; 21 USD/m3
	RN.logsPricePerLiter.POPLAR				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.POPLAR			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.POPLAR				= 7.5;
	RN.lumberPriceVariation.POPLAR			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.RAVAGED 					= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.RAVAGED 			= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.RAVAGED 		= 1200;	-- Price per MBFT
	RN.logsPricePerLiter.RAVAGED			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.RAVAGED 			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.RAVAGED 			= 3.0;
	RN.lumberPriceVariation.RAVAGED 		= 30;	-- Percent price variation on tree logs

	RN.woodDensity.SHAGBARKHICKORY 				= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.SHAGBARKHICKORY 		= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.SHAGBARKHICKORY 	= 1200;	-- Price per MBFT
	RN.logsPricePerLiter.SHAGBARKHICKORY		= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.SHAGBARKHICKORY 		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.SHAGBARKHICKORY 		= 3.0;
	RN.lumberPriceVariation.SHAGBARKHICKORY 	= 30;	-- Percent price variation on tree logs

	RN.woodDensity.SPRUCE					= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.SPRUCE				= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.SPRUCE		= 450;	-- Price per MBFT 150
	RN.logsPricePerLiter.SPRUCE				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.SPRUCE			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.SPRUCE				= 3.0;
	RN.lumberPriceVariation.SPRUCE			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.STONEPINE 				= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.STONEPINE 			= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.STONEPINE 	= 450;	-- Price per MBFT 150   -- 300eu/m3
	RN.logsPricePerLiter.STONEPINE			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.STONEPINE 		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.STONEPINE 			= 3.0;
	RN.lumberPriceVariation.STONEPINE 		= 30;	-- Percent price variation on tree logs

	RN.woodDensity.TILIAAMURENSIS					= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.TILIAAMURENSIS				= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.TILIAAMURENSIS		= 450;	-- Price per MBFT 150
	RN.logsPricePerLiter.TILIAAMURENSIS				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.TILIAAMURENSIS			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.TILIAAMURENSIS				= 3.0;
	RN.lumberPriceVariation.TILIAAMURENSIS			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.TRANSPORT				= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.TRANSPORT			= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.TRANSPORT		= 450;	-- Price per MBFT 150
	RN.logsPricePerLiter.TRANSPORT			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.TRANSPORT		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.TRANSPORT			= 3.0;
	RN.lumberPriceVariation.TRANSPORT		= 30;	-- Percent price variation on tree logs

	RN.woodDensity.WILLOW 					= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.WILLOW 			= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.WILLOW 		= 1000;	-- Price per MBFT 150
	RN.logsPricePerLiter.WILLOW				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.WILLOW 			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.WILLOW 			= 3.0;
	RN.lumberPriceVariation.WILLOW 			= 30;	-- Percent price variation on tree logs

	RN.woodDensity.DEADWOOD 				= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.DEADWOOD 			= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.DEADWOOD 		= 450;	-- Price per MBFT 150   -- 300eu/m3
	RN.logsPricePerLiter.DEADWOOD			= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.DEADWOOD 		= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.DEADWOOD 			= 3.0;
	RN.lumberPriceVariation.DEADWOOD 		= 30;	-- Percent price variation on tree logs

	RN.woodDensity.APPLE 					= 0.55; -- kg/L/
	RN.tonnesWoodPerMBFT.APPLE 				= 7.0;	-- Tonnes / MBFT
	RN.milledWoodPricePerMBFT.APPLE 		= 1000;	-- Price per MBFT 150
	RN.logsPricePerLiter.APPLE				= 0;	-- Price per cubic meter, if = 0, then it is derived from logPricePerMBFT
	RN.woodDeliveryPerMBFT.APPLE 			= 89.0; -- Price per MBFT
	RN.woodChipsPerLiter.APPLE 				= 3.0;
	RN.lumberPriceVariation.APPLE 			= 30;	-- Percent price variation on tree logs




-- create a list of trees on the map and save in a table called treeList

	local treeList = {};
	for i,v in pairs(g_splitShapeManager.typesByIndex) do
		treeList[i] = string.upper(v.name);
--		print(v.name);
	end;


-- sort treeList alphabetically and save in sortedTrees

	local sortedTrees = {};
	for i,n in pairs(treeList) do table.insert(sortedTrees,n); end;
	table.sort(sortedTrees);
--	DebugUtil.printTableRecursively(g_splitShapeManager,"_",0,4);
	RN.sortedTrees = sortedTrees;
	for k,treeName in ipairs(sortedTrees) do
		print(treeName)				-- treeName are names of trees defined on the map.

		if string.find(RN.loggingTrees.names,treeName) ~= nil then
			RN.treeRandomPriceFactor[treeName] = 1 + randomness * RN.lumberPriceVariation[treeName] * (math.random()-0.5)/100;
			RN.logsPricePerMBFT[treeName]			= RN.treeRandomPriceFactor[treeName] * RN.milledWoodPricePerMBFT[treeName] - RN.totalLumberYardCost;
			RN.logsPricePerTonnes[treeName] 		= RN.logsPricePerMBFT[treeName]/RN.tonnesWoodPerMBFT[treeName];
			RN.logsPricePerLiter[treeName] 			= RN.logsPricePerTonnes[treeName]    * RN.woodDensity[treeName];

			myPrintFloat(treeName.." : wood mass density ",RN.woodDensity[treeName],textWidth,"kg/L");
			myPrintFloat(treeName.." : Tonnes per 1000 board feet ",RN.tonnesWoodPerMBFT[treeName],textWidth,"Tonnes/MBFT");
			myPrint(treeName.." : Milled wood per MBFT",RN.treeRandomPriceFactor[treeName] * RN.milledWoodPricePerMBFT[treeName],textWidth,currency.."/MBFT");
			myPrint(treeName.." : Lumber yard deductions",RN.totalLumberYardCost,textWidth,currency.."/MBFT");
			myPrint(treeName.." : Logs per MBFT",RN.logsPricePerMBFT[treeName],textWidth,currency.."/MBFT");
			myPrint(treeName.." : Logs per Tonnes",RN.logsPricePerTonnes[treeName],textWidth,currency.."/Tonnes");
			myPrint(treeName.." : Logs per 1000 liters ",RN.logsPricePerLiter[treeName],textWidth,currency.."/1000 L");
			myPrintFloat(treeName.." : Woodchips per liter ",RN.woodChipsPerLiter[treeName],textWidth,currency.."/Liter")
		else
			print(treeName.." is not defined in FS25_RealLifeNumbers");
		end;
		print(" ");
	end;
end;


function RealNumbersTreeLogPrices:keyEvent(unicode, sym, modifier, isDown)
	local currency = "€";	-- or  "$" or "£"
    local textWidth1 = 40; 	-- text width in log file
	local textWidth = 60;
	local textWidth2 = 15;
	local randomness = 1; 	--1: on, 0: off

	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end
	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_q) then
		print(" ");
		print("\n --- lAlt-rq pressed:  RealNumbersTreeLogPrices.lua --- \n");

		print("MBFT : 1000 board feet = 1000 square feet x 1 inch thick = 2.35973722 cubic meters");
		print("Tonnes per MBFT is how many tonnes of barked tree logs is needed to produce 2.36 cubic meters of cut boards");
		print("Price per milled MBFT is the input price. Adjust this in RealNumbersTreeLogPrices");
		print("Random price variation is used to simulate variation in log quality");
		print("Random price variation can be adjusted in RealNumbersTreeLogPrices.lua");
		print("Random price variation can be turned off in RealNumbersTreeLogPrices.lua");
		print("Fixed and variable lumber yard costs are deducted from milled wood prices");
		print("to obtain price per MBFT for harvested and delivered logs.");
		print("Log prices are converted to tonnes and 1000 L");
		print(" ");

-- create a list of trees on the map and save in a table called treeList

		local treeList = {};
		for i,v in pairs(g_splitShapeManager.typesByIndex) do
			treeList[i] = string.upper(v.name);
		end;


-- sort treeList alphabetically and save in sortedTrees

		local sortedTrees = {};
		for i,n in pairs(treeList) do table.insert(sortedTrees,n); end;
		table.sort(sortedTrees);
		RN.sortedTrees = sortedTrees;
			for k,treeName in ipairs(sortedTrees) do
				print(treeName)				-- treeName are names of trees defined on the map.

				if string.find(RN.loggingTrees.names,treeName) ~= nil then
					myPrintFloat(treeName.." : wood mass density ",RN.woodDensity[treeName],textWidth,"kg/L");
					myPrintFloat(treeName.." : Tonnes per 1000 board feet ",RN.tonnesWoodPerMBFT[treeName],textWidth,"Tonnes/MBFT");
					myPrint(treeName.." : Milled wood per MBFT",RN.treeRandomPriceFactor[treeName] * RN.milledWoodPricePerMBFT[treeName],textWidth,currency.."/MBFT");
					myPrint(treeName.." : Lumber yard deductions",RN.totalLumberYardCost,textWidth,currency.."/MBFT");
					myPrint(treeName.." : Logs per MBFT",RN.logsPricePerMBFT[treeName],textWidth,currency.."/MBFT");
					myPrint(treeName.." : Logs per Tonnes",RN.logsPricePerTonnes[treeName],textWidth,currency.."/Tonnes");
					myPrint(treeName.." : Logs per 1000 liters ",RN.logsPricePerLiter[treeName],textWidth,currency.."/1000 L");
					myPrintFloat(treeName.." : Woodchips per liter ",RN.woodChipsPerLiter[treeName],textWidth,currency.."/Liter")
				else
					print(treeName.." is not defined in FS25_RealLifeNumbers");
				end;
			print(" ");
		end;
	end;
end;


function RealNumbersTreeLogPrices:update(dt)

	local minute = g_currentMission.environment.currentMinute;


	local runMinute = minute % 10; -- remainder
	if runMinute ~= 5 then RN.notRunYetRealNumbersTreeLogPrices = true; end;
	if runMinute == 5 or RN.upStartRealNumbersTreeLogPrices then
		if RN.notRunYetRealNumbersTreeLogPrices then

--			print(" --- RealNumbersTreeLogPrices:update"); -- comment out when not debugging

			if g_splitShapeManager ~= nil then
				for k,tree in pairs(g_splitShapeManager.typesByIndex) do
					local name = string.upper(tree.name);
					if RN.woodChipsPerLiter[name] ~= nil then
						tree.woodChipsPerLiter = RN.woodChipsPerLiter[name];
					end;
					if RN.logsPricePerLiter[name] ~= nil then
						tree.pricePerLiter = RN.logsPricePerLiter[name]/1000;
					end;
				end;
			end;

		end;
		RN.notRunYetRealNumbersTreeLogPrices = false;
		RN.upStartRealNumbersTreeLogPrices = false;
	end;
end;
function RealNumbersTreeLogPrices:draw()
end;
function RealNumbersTreeLogPrices:deleteMap()
end;
function RealNumbersTreeLogPrices:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersTreeLogPrices);

